@@ -48,12 +48,28 @@ from mysql.connector.pooling import PooledMySQLConnection
 # Local Folder (Relative) Imports
 from .. import exceptions, utils
 
+# psycopg2 is defined as an optional dependency. We use this try/except
+# to gracefully handle environments where psycopg2 is not installed
+# (e.g., on older systems or when Postgres support is not needed).
+# If you do need Postgres support, run:
+#     pip install "carlogtt-python-library[postgres]"
 try:
     import psycopg2
     import psycopg2.extensions
     import psycopg2.extras
+
+    PGConnection = psycopg2.extensions.connection
+
 except ImportError:
-    pass
+    # Setting up logger for current module
+    module_logger = logging.getLogger(__name__)
+    module_logger.debug(
+        "psycopg2 is not installed. Please install manually or use 'pip install"
+        " \"carlogtt-python-library[postgres]\"'."
+    )
+
+    psycopg2 = None  # type: ignore
+    PGConnection = NotImplemented  # type: ignore
 
 
 # END IMPORTS
@@ -287,10 +303,10 @@ class PostgreSQL(Database):
         self._password = password
         self._port = port
         self._database_schema = database_schema
-        self._db_connection: Optional[psycopg2.extensions.connection] = None
+        self._db_connection: Optional[PGConnection] = None
 
     @property
-    def db_connection(self) -> psycopg2.extensions.connection:
+    def db_connection(self) -> PGConnection:
         """
         Gets the active db connection. If there is not an active
         connection it creates one.
